cloudsync.Notification
===============================================

.. autoclass:: cloudsync.Notification
   :members:
   :undoc-members:

.. autoclass:: cloudsync.NotificationType
   :members:
   :undoc-members:
